[ ] filtration, you can't see the names of the deeper categories unless you have unlocked the shallow categories. [ ] nudity 13+ [ ] erotic 18+ [ ] violence 15+ [ ] gore 25+ [ ] death 25+ [ ] drug use 13+ [ ] glorifying drug use 20+ filtration chart: [{ "names": [ "nudity" ], "restrictions": { "age": "13+" }, "filters": [{ "names": "erotic", "restrictions": { "age": "18+" } }] }] { "names": [ "a directory" ], "filters": [ "nudity" ] }